@@ -44,8 +44,8 @@ pub struct PluginsLs {
 impl PluginsLs {
     pub fn run(self, config: &Config) -> Result<()> {
         let mut plugins: BTreeMap<_, _> = install_state::list_plugins()?
-            .into_iter()
-            .map(|(k, p)| (k, (p, None)))
+            .iter()
+            .map(|(k, p)| (k.clone(), (*p, None)))
             .collect();
 
         if self.core {
@@ -138,39 +138,3 @@ static AFTER_LONG_HELP: &str = color_print::cstr!(
     ruby    https://github.com/asdf-vm/asdf-ruby.git
 "#
 );
-
-#[cfg(test)]
-mod tests {
-    use insta::assert_snapshot;
-    use test_log::test;
-
-    use crate::cli::tests::grep;
-    use crate::test::reset;
-
-    #[test]
-    fn test_plugin_list() {
-        reset();
-        assert_cli_snapshot!("plugin", "list");
-    }
-
-    #[test]
-    fn test_plugin_list_urls() {
-        reset();
-        let stdout = assert_cli!("plugin", "list", "--urls");
-        assert!(stdout.contains("dummy"))
-    }
-
-    #[test]
-    fn test_plugin_list_all() {
-        reset();
-        let stdout = assert_cli!("plugin", "list", "--all", "--urls");
-        assert_snapshot!(grep(stdout, "zephyr"));
-    }
-
-    #[test]
-    fn test_plugin_refs() {
-        reset();
-        let stdout = assert_cli!("plugin", "list", "--refs");
-        assert!(stdout.contains("dummy"))
-    }
-}
