@@ -1,7 +1,7 @@
 use eyre::{bail, Result};
 use serde_json::json;
 
-use crate::config::CONFIG;
+use crate::config::Config;
 use crate::file::display_path;
 use crate::task::Task;
 use crate::ui::info;
@@ -20,7 +20,8 @@ pub struct TasksInfo {
 
 impl TasksInfo {
     pub fn run(self) -> Result<()> {
-        let task = CONFIG.tasks()?.get(&self.task);
+        let config = Config::get();
+        let task = config.tasks()?.get(&self.task);
 
         if let Some(task) = task {
             if self.json {
@@ -136,54 +137,3 @@ static AFTER_LONG_HELP: &str = color_print::cstr!(
     }
 "#
 );
-
-#[cfg(test)]
-mod tests {
-    use crate::test::reset;
-    use test_log::test;
-
-    #[test]
-    fn test_task_info() {
-        reset();
-        assert_cli_snapshot!("task", "info", "filetask", @r#"
-        Task: filetask
-        Aliases: ft
-        Description: This is a test build script
-        Source: ~/cwd/.mise/tasks/filetask
-        Depends on: lint, test
-        Sources: .test-tool-versions
-        Outputs: $MISE_PROJECT_ROOT/test/test-build-output.txt
-        File: ~/cwd/.mise/tasks/filetask
-
-        Environment Variables:
-          BOOLEAN_VAR = true
-          TEST_BUILDSCRIPT_ENV_VAR = "VALID"
-
-        Usage Spec:
-          name "filetask"
-          bin "filetask"
-          flag "--user" help="The user to run as" {
-              arg "<user>"
-          }
-        "#);
-        assert_cli_snapshot!("task", "info", "test", @r#"
-        Task: test
-        Description:
-        Source: ~/config/config.toml
-
-        Run:
-          echo "testing!"
-
-        Usage Spec:
-          name "test"
-          bin "test"
-        "#);
-    }
-
-    #[test]
-    fn test_task_info_json() {
-        reset();
-        assert_cli_snapshot!("task", "info", "filetask", "--json");
-        assert_cli_snapshot!("task", "info", "test", "--json");
-    }
-}
