@@ -213,34 +213,42 @@ impl EnvResults {
                     }
                 }
                 EnvDirective::File(input) => {
-                    trust_check(&source)?;
                     let s = r.parse_template(&ctx, &source, input.to_string_lossy().as_ref())?;
-                    for p in xx::file::glob(normalize_path(&config_root, s.into()))? {
+                    for p in
+                        xx::file::glob(normalize_path(&config_root, s.into())).unwrap_or_default()
+                    {
                         r.env_files.push(p.clone());
                         let errfn = || eyre!("failed to parse dotenv file: {}", display_path(&p));
-                        for item in dotenvy::from_path_iter(&p).wrap_err_with(errfn)? {
-                            let (k, v) = item.wrap_err_with(errfn)?;
-                            r.env_remove.remove(&k);
-                            env.insert(k, (v, Some(p.clone())));
+                        if let Ok(dotenv) = dotenvy::from_path_iter(&p) {
+                            for item in dotenv {
+                                let (k, v) = item.wrap_err_with(errfn)?;
+                                r.env_remove.remove(&k);
+                                env.insert(k, (v, Some(p.clone())));
+                            }
                         }
                     }
                 }
                 EnvDirective::Source(input) => {
                     SETTINGS.ensure_experimental("env._.source")?;
-                    trust_check(&source)?;
-                    let s = r.parse_template(&ctx, &source, input.to_string_lossy().as_ref())?;
-                    for p in xx::file::glob(normalize_path(&config_root, s.into()))? {
-                        r.env_scripts.push(p.clone());
-                        let env_diff = EnvDiff::from_bash_script(&p, env_vars.clone())?;
-                        for p in env_diff.to_patches() {
-                            match p {
-                                EnvDiffOperation::Add(k, v) | EnvDiffOperation::Change(k, v) => {
-                                    r.env_remove.remove(&k);
-                                    env.insert(k.clone(), (v.clone(), Some(source.clone())));
-                                }
-                                EnvDiffOperation::Remove(k) => {
-                                    env.shift_remove(&k);
-                                    r.env_remove.insert(k);
+                    if let Ok(s) = r.parse_template(&ctx, &source, input.to_string_lossy().as_ref())
+                    {
+                        for p in xx::file::glob(normalize_path(&config_root, s.into()))
+                            .unwrap_or_default()
+                        {
+                            r.env_scripts.push(p.clone());
+                            let env_diff =
+                                EnvDiff::from_bash_script(&p, env_vars.clone()).unwrap_or_default();
+                            for p in env_diff.to_patches() {
+                                match p {
+                                    EnvDiffOperation::Add(k, v)
+                                    | EnvDiffOperation::Change(k, v) => {
+                                        r.env_remove.remove(&k);
+                                        env.insert(k.clone(), (v.clone(), Some(source.clone())));
+                                    }
+                                    EnvDiffOperation::Remove(k) => {
+                                        env.shift_remove(&k);
+                                        r.env_remove.insert(k);
+                                    }
                                 }
                             }
                         }
@@ -253,6 +261,7 @@ impl EnvResults {
                     let venv = normalize_path(&config_root, venv.into());
                     if !venv.exists() && create {
                         // TODO: the toolset stuff doesn't feel like it's in the right place here
+                        // TODO: in fact this should probably be moved to execute at the same time as src/uv.rs runs in ts.env() instead of config.env()
                         let config = Config::get();
                         let ts = ToolsetBuilder::new().build(&config)?;
                         let path = ts
@@ -267,11 +276,14 @@ impl EnvResults {
                         {
                             debug!("python not installed, skipping venv creation");
                         } else {
-                            let cmd = if let (false, Some(_uv_in_path)) =
-                                (SETTINGS.python.venv_stdlib, which_non_pristine("uv"))
-                            {
+                            let has_uv_bin =
+                                ts.which("uv").is_some() || which_non_pristine("uv").is_some();
+                            let use_uv = !SETTINGS.python.venv_stdlib && has_uv_bin;
+                            let cmd = if use_uv {
+                                info!("creating venv with uv at: {}", display_path(&venv));
                                 CmdLineRunner::new("uv").args(["venv", &venv.to_string_lossy()])
                             } else {
+                                info!("creating venv with stdlib at: {}", display_path(&venv));
                                 CmdLineRunner::new("python3").args([
                                     "-m",
                                     "venv",
@@ -283,7 +295,6 @@ impl EnvResults {
                                 PATH_KEY.to_string(),
                                 env::join_paths(&path)?.to_string_lossy().to_string(),
                             );
-                            info!("creating venv at: {}", display_path(&venv));
                             cmd.execute()?;
                         }
                     }
@@ -392,17 +403,17 @@ impl Debug for EnvResults {
 }
 
 #[cfg(test)]
+#[cfg(unix)]
 mod tests {
     use insta::assert_debug_snapshot;
     use test_log::test;
 
-    use crate::test::{replace_path, reset};
+    use crate::test::replace_path;
 
     use super::*;
 
     #[test]
     fn test_env_path() {
-        reset();
         let mut env = HashMap::new();
         env.insert("A".to_string(), "1".to_string());
         env.insert("B".to_string(), "2".to_string());
@@ -444,7 +455,6 @@ mod tests {
 
     #[test]
     fn test_venv_path() {
-        reset();
         let env = HashMap::new();
         let results = EnvResults::resolve(
             &env,
