@@ -94,7 +94,7 @@ pub static MISE_DEFAULT_CONFIG_FILENAME: Lazy<String> = Lazy::new(|| {
     var("MISE_DEFAULT_CONFIG_FILENAME")
         .ok()
         .or(MISE_OVERRIDE_CONFIG_FILENAMES.first().cloned())
-        .or(MISE_ENV.as_ref().map(|env| format!("mise.{env}.toml")))
+        .or(MISE_ENV.last().map(|env| format!("mise.{env}.toml")))
         .unwrap_or_else(|| "mise.toml".into())
 });
 pub static MISE_OVERRIDE_TOOL_VERSIONS_FILENAMES: Lazy<Option<IndexSet<String>>> =
@@ -108,7 +108,7 @@ pub static MISE_OVERRIDE_CONFIG_FILENAMES: Lazy<IndexSet<String>> =
         Ok(v) => v.split(':').map(|s| s.to_string()).collect(),
         Err(_) => Default::default(),
     });
-pub static MISE_ENV: Lazy<Option<String>> = Lazy::new(|| environment(&ARGS.read().unwrap()));
+pub static MISE_ENV: Lazy<Vec<String>> = Lazy::new(|| environment(&ARGS.read().unwrap()));
 pub static MISE_GLOBAL_CONFIG_FILE: Lazy<PathBuf> = Lazy::new(|| {
     var_path("MISE_GLOBAL_CONFIG_FILE")
         .or_else(|| var_path("MISE_CONFIG_FILE"))
@@ -154,7 +154,13 @@ pub static MISE_TIMINGS: Lazy<u8> = Lazy::new(|| var_u8("MISE_TIMINGS"));
 pub static MISE_PID: Lazy<String> = Lazy::new(|| process::id().to_string());
 pub static __MISE_SCRIPT: Lazy<bool> = Lazy::new(|| var_is_true("__MISE_SCRIPT"));
 pub static __MISE_DIFF: Lazy<EnvDiff> = Lazy::new(get_env_diff);
-pub static __MISE_DIR: Lazy<Option<PathBuf>> = Lazy::new(|| var_path("__MISE_DIR"));
+/// the directory where hook-env was last run from
+/// prefixed with ":" so it does not conflict with zsh's auto_name_dirs feature
+pub static __MISE_DIR: Lazy<Option<PathBuf>> = Lazy::new(|| {
+    var("__MISE_DIR")
+        .map(|d| PathBuf::from(d.strip_prefix(":").unwrap_or(&d)))
+        .ok()
+});
 pub static __MISE_ORIG_PATH: Lazy<Option<String>> = Lazy::new(|| var("__MISE_ORIG_PATH").ok());
 pub static __MISE_WATCH: Lazy<Option<HookEnvWatches>> = Lazy::new(|| match var("__MISE_WATCH") {
     Ok(raw) => deserialize_watches(raw)
@@ -410,7 +416,7 @@ fn prefer_stale(args: &[String]) -> bool {
     .contains(&c.as_str())
 }
 
-fn environment(args: &[String]) -> Option<String> {
+fn environment(args: &[String]) -> Vec<String> {
     let arg_defs = HashSet::from([
         format!("--{}", PROFILE_ARG.get_long().unwrap_or_default()),
         format!("-{}", PROFILE_ARG.get_short().unwrap_or_default()),
@@ -429,6 +435,11 @@ fn environment(args: &[String]) -> Option<String> {
         .or_else(|| var("MISE_ENV").ok())
         .or_else(|| var("MISE_PROFILE").ok())
         .or_else(|| var("MISE_ENVIRONMENT").ok())
+        .unwrap_or_default()
+        .split(',')
+        .filter(|s| !s.is_empty())
+        .map(String::from)
+        .collect()
 }
 
 fn log_file_level() -> Option<LevelFilter> {
