@@ -1,3 +1,4 @@
+use std::fmt::Display;
 use std::path::Path;
 
 use indoc::formatdoc;
@@ -104,6 +105,12 @@ impl Shell for Bash {
     }
 }
 
+impl Display for Bash {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "bash")
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use insta::assert_snapshot;
