@@ -1,8 +1,8 @@
+use std::fmt::Display;
 use std::path::Path;
 
-use indoc::formatdoc;
-
 use crate::shell::Shell;
+use indoc::formatdoc;
 
 #[derive(Default)]
 pub struct Elvish {}
@@ -84,6 +84,12 @@ impl Shell for Elvish {
     }
 }
 
+impl Display for Elvish {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "elvish")
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use insta::assert_snapshot;
