@@ -1,3 +1,4 @@
+use std::fmt::{Display, Formatter};
 use std::path::Path;
 
 use crate::config::Settings;
@@ -126,6 +127,12 @@ impl Shell for Fish {
     }
 }
 
+impl Display for Fish {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "fish")
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use insta::assert_snapshot;
