@@ -1,4 +1,5 @@
 use std::borrow::Cow;
+use std::fmt::Display;
 use std::path::Path;
 
 use indoc::formatdoc;
@@ -138,6 +139,12 @@ impl Shell for Xonsh {
     }
 }
 
+impl Display for Xonsh {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "xonsh")
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use insta::assert_snapshot;
