@@ -1,4 +1,4 @@
-use crate::config::CONFIG;
+use crate::config::Config;
 use crate::tera::{get_tera, BASE_CONTEXT};
 use eyre::Result;
 use indexmap::IndexMap;
@@ -263,7 +263,7 @@ impl TaskScriptParser {
         ctx.insert("config_root", config_root);
         let mut vars = IndexMap::new();
         ctx.insert("vars", &vars);
-        for (k, v) in &CONFIG.vars {
+        for (k, v) in &Config::get().vars {
             vars.insert(k.clone(), tera.render_str(v, &ctx).unwrap());
             ctx.insert("vars", &vars);
         }
@@ -330,11 +330,9 @@ pub fn has_any_args_defined(spec: &usage::Spec) -> bool {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::test::reset;
 
     #[test]
     fn test_task_parse_arg() {
-        reset();
         let parser = TaskScriptParser::new(None);
         let scripts = vec!["echo {{ arg(i=0, name='foo') }}".to_string()];
         let (scripts, spec) = parser.parse_run_scripts(&None, &scripts).unwrap();
@@ -349,7 +347,6 @@ mod tests {
 
     #[test]
     fn test_task_parse_arg_var() {
-        reset();
         let parser = TaskScriptParser::new(None);
         let scripts = vec!["echo {{ arg(var=true) }}".to_string()];
         let (scripts, spec) = parser.parse_run_scripts(&None, &scripts).unwrap();
@@ -368,7 +365,6 @@ mod tests {
 
     #[test]
     fn test_task_parse_flag() {
-        reset();
         let parser = TaskScriptParser::new(None);
         let scripts = vec!["echo {{ flag(name='foo') }}".to_string()];
         let (scripts, spec) = parser.parse_run_scripts(&None, &scripts).unwrap();
@@ -384,7 +380,6 @@ mod tests {
 
     #[test]
     fn test_task_parse_option() {
-        reset();
         let parser = TaskScriptParser::new(None);
         let scripts = vec!["echo {{ option(name='foo') }}".to_string()];
         let (scripts, spec) = parser.parse_run_scripts(&None, &scripts).unwrap();
